import waba.ui.*;
import waba.fx.*;
import waba.sys.*;


public class DrawArea extends Control 
{
	Graphics gDraw, gBuffer;
	Image bufferImage;
	
	int pieces=2;	
	int n1, n2, n3, n4;
	int randSeed;
	
	boolean sound=true;

public void onEvent(Event event)
	{	
		if (event.type == PenEvent.PEN_DOWN)				
		{
			RollDices();			

			UpdateDice(gDraw);

			if(sound)PlaySound();
		}		
	}

public void ProcessKeyPress()
{
	RollDices();			

	UpdateDice(gDraw);

	if(sound)PlaySound();
}

public void onPaint(Graphics g)
	{	
		if(gDraw!=null)
			UpdateDice(gDraw);

		else		
			Initialize();						
	}

void Initialize()
{
	gDraw = createGraphics();
	gDraw.setClip(0, 0, this.width, this.height);
			
	bufferImage = new Image(this.width, this.height);
	gBuffer = new Graphics(bufferImage);			

	Randomize();

	RollDices();
	UpdateDice(gDraw);			
}

void UpdateDice(Graphics g)
	{
		// erase draw area in white
		gBuffer.setColor(255,255,255);
		gBuffer.fillRect(0, 0, this.width, this.height);

		if(pieces==1)
			DrawBigDice();

		else
			DrawSmallDices(pieces);		

		// copy buffer to screen
		g.drawImage(bufferImage, 0, 0);		
	}

void DrawBigDice()
	{
		int xOff=40;
		int yOff=20;

		Image dice = new Image("dice.bmp");	

		gBuffer.drawImage(dice, xOff, yOff);

		Image dot = new Image("dot.bmp");

		if(n1==1||n1==3||n1==5)
			//center
			gBuffer.drawImage(dot, 33+xOff, 33+yOff);

		if(n1==4||n1==5||n1==6)
			//nw		
			gBuffer.drawImage(dot, 13+xOff, 13+yOff);

		if(n1>1)
		{
			//ne
			gBuffer.drawImage(dot, 53+xOff, 13+yOff);		
			//sw
			gBuffer.drawImage(dot, 13+xOff, 53+yOff);
		}

		if(n1>3)
			//se
			gBuffer.drawImage(dot, 53+xOff, 53+yOff);
		
		if(n1==6)
		{
			gBuffer.drawImage(dot, 13+xOff, 33+yOff);
			gBuffer.drawImage(dot, 53+xOff, 33+yOff);
		}
	}

void DrawSmallDices(int d)
	{
		Image dice = new Image("dice1.bmp");
		Image dot = new Image("dot1.bmp");

		int xOff=0;
		int yOff=0;	
		
		int n=0;

		for(int i=0; i<d; i++)
		{
			//2 dices
			if(d==2)
			{
				if(i==0)
				{
					xOff=30;
					yOff=60;
				}
				else
				{
					xOff=90;
					yOff=20;
				}
			}

			//3 dices
			if(d==3)
			{
				if(i==0)
				{
					xOff=20;
					yOff=65;
				}
				if(i==1)
				{
					xOff=50;
					yOff=15;
				}
				if(i==2)
				{
					xOff=100;
					yOff=45;
				}
			}

			//4 dices
			if(d==4)
			{
				if(i==0)
				{
					xOff=30;
					yOff=10;
				}
				if(i==1)
				{
					xOff=90;
					yOff=15;
				}
				if(i==2)
				{
					xOff=25;
					yOff=65;
				}
				if(i==3)
				{
					xOff=93;
					yOff=62;
				}
			}

			if(i==0)n=n1;
			if(i==1)n=n2;
			if(i==2)n=n3;
			if(i==3)n=n4;

			gBuffer.drawImage(dice, xOff, yOff);			

			if(n==1||n==3||n==5)
				//center
				gBuffer.drawImage(dot, 15+xOff, 15+yOff);

			if(n==4||n==5||n==6)
				//nw		
				gBuffer.drawImage(dot, 6+xOff, 6+yOff);

			if(n>1)
			{
				//ne
				gBuffer.drawImage(dot, 25+xOff, 6+yOff);		
				//sw
				gBuffer.drawImage(dot, 6+xOff, 24+yOff);
			}

			if(n>3)
				//se
				gBuffer.drawImage(dot, 25+xOff, 24+yOff);
			
			if(n==6)
			{
				gBuffer.drawImage(dot, 6+xOff, 15+yOff);
				gBuffer.drawImage(dot, 25+xOff, 15+yOff);
			}
		}
	}

void RollDices()
{
	n1=Rand(6)+1;
	
	if(pieces>1)
		n2=Rand(6)+1;

	if(pieces>2)
		n3=Rand(6)+1;

	if(pieces>3)
		n4=Rand(6)+1;

	if(pieces<2){n2=n3=n4=0;};
	if(pieces<3){n3=n4=0;};
	if(pieces<4)n4=0;
}

void Randomize()
{
	Time t = new Time();

	randSeed = t.hour+t.minute+t.second+t.millis;	
}

int Rand(int range) 
{
	// RAND_MAX assumed to be 32767
	randSeed = randSeed * 1103515245 + 12345;
	int n = (int)(randSeed/65536) % 32768;  

	if(n<0)
		return -n%range;

	return n%range;
}

void SetNumber(int n)
{
	pieces=n;

	RollDices();
	UpdateDice(gDraw);
}

void SetSound(boolean s)
{
	sound=s;
}

void PlaySound()
{
	if(n1==6||n2==6||n3==6||n4==6)
	{
		for(int i=0;i<5;i++)
		Sound.tone(500+i*500, 50);
	}
	else
		Sound.tone(500, 50);
}

}
